def success_response(message, data=None):
    return {"message": message, "data": data, "status": "success"}

def error_response(message, status_code=400):
    return {"message": message, "status": "error"}, status_code