from flask import Blueprint, jsonify
from flask_jwt_extended import jwt_required

user_bp = Blueprint("user", __name__)

@user_bp.route("/profile", methods=["GET"])
@jwt_required()
def profile():
    return jsonify({"message": "User profile data"})
