from setuptools import setup, find_packages

setup(
    name='flask_backend_template',  # Unique package name
    version='0.1.0',
    author='Arjun Shukla',
    author_email='arjunshukla6558@gmail.com',
    description='A modular Flask backend template ',
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[
        'Flask',
        'Flask-SQLAlchemy',
        'Flask-JWT-Extended',
        'Flask-CORS',
        'Werkzeug',
        'python-dotenv'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
